@@ -122,10 +122,11 @@ def test_changelog():
 
 ### Issues Closed
 
+* [Issue 77](https://github.com/spyder-ide/loghub/issues/77) - Test empty body
 * [Issue 26](https://github.com/spyder-ide/loghub/issues/26) - Test number 2
 * [Issue 24](https://github.com/spyder-ide/loghub/issues/24) - Issue test
 
-In this release 2 issues were closed.
+In this release 3 issues were closed.
 
 ### Pull Requests Merged
 
@@ -150,10 +151,11 @@ def test_changelog_release():
 
 ### Issues Closed
 
+* Issue #77 - Test empty body
 * Issue #26 - Test number 2
 * Issue #24 - Issue test
 
-In this release 2 issues were closed.
+In this release 3 issues were closed.
 
 ### Pull Requests Merged
 
@@ -178,16 +180,18 @@ def test_changelog_release_branch():
 
 ### Issues Closed
 
+* Issue #77 - Test empty body
 * Issue #26 - Test number 2
 * Issue #24 - Issue test
 
-In this release 2 issues were closed.
+In this release 3 issues were closed.
 
 ### Pull Requests Merged
 
+* PR #84 - Test no issue number in PR's body
 * PR #33 - PR: Test change
 
-In this release 1 pull request was closed.
+In this release 2 pull requests were closed.
 '''
     print([log])
     print([expected])
@@ -215,9 +219,10 @@ In this release 1 issue was closed.
 
 ### Pull Requests Merged
 
+* [PR 84](https://github.com/spyder-ide/loghub/pull/84) - Test no issue number in PR's body
 * [PR 33](https://github.com/spyder-ide/loghub/pull/33) - PR: Test change
 
-In this release 1 pull request was closed.
+In this release 2 pull requests were closed.
 '''
     print([log])
     print([expected])
@@ -238,7 +243,7 @@ def test_changelog_template():
         token=TEST_TOKEN,
         milestone=TEST_MILESTONE,
         template_file=path)
-    expected = '* Issue #26 - Test number 2\n* Issue #24 - Issue test\n'
+    expected = '* Issue #77 - Test empty body\n* Issue #26 - Test number 2\n* Issue #24 - Issue test\n'
     print([log])
     print([expected])
     assert log == expected
